#!/usr/bin/env python

__version__ = '0.1'
    
_nvd = '{http://scap.nist.gov/schema/feed/vulnerability/2.0}'
_vuln = '{http://scap.nist.gov/schema/vulnerability/0.4}'

class CVE:

    def __init__(self, el):
        self.id = el.attrib['id']
        self.summary = el.findtext('./{}summary'.format(_vuln))
        self.products = []
        for e in el.iterfind('./{0}vulnerable-software-list/{0}product'.format(_vuln)):
            self.products.append(e.text[7:])

class NVD:

    recent_url = 'https://nvd.nist.gov/feeds/xml/cve/nvdcve-2.0-recent.xml'

    def __init__(self):
        self.update()

    def update(self):
        tree = NVD.fetch_recent()
        self.cves = {}
        for e in tree.iterfind('./{}entry'.format(_nvd)):
            cve = CVE(e)
            self.cves[cve.id] = cve

    @classmethod
    def fetch_recent(cls):
        import io
        from urllib.request import urlopen
        from xml.etree.ElementTree import parse
        return parse(io.BytesIO(urlopen(cls.recent_url).read()))

if __name__ == '__main__':
    nvd = NVD()
    for k in nvd.cves:
        cve = nvd.cves[k]
        print('{} ({}): {}'.format(k, ','.join(cve.products), cve.summary))
